@@ -29,6 +29,10 @@ class ImagePart(Part):
         )
         self._filename = filename
 
+    @classmethod
+    def load(cls, partname, content_type, blob, package):
+        return cls(partname, content_type, blob, package)
+
     @classmethod
     def new(cls, package, image):
         """
@@ -40,6 +44,20 @@ class ImagePart(Part):
             partname, image.content_type, image.blob, package, image.filename
         )
 
+    @property
+    def desc(self):
+        """
+        The filename associated with this image, either the filename of
+        the original image or a generic name of the form ``image.ext``
+        where ``ext`` is appropriate to the image file format, e.g.
+        ``'jpg'``. An image created using a path will have that filename; one
+        created with a file-like object will have a generic name.
+        """
+        # return generic filename if original filename is unknown
+        if self._filename is None:
+            return 'image.%s' % self.ext
+        return self._filename
+
     @property
     def ext(self):
         """
@@ -47,9 +65,12 @@ class ImagePart(Part):
         """
         return self.partname.ext
 
-    @classmethod
-    def load(cls, partname, content_type, blob, package):
-        return cls(partname, content_type, blob, package)
+    @property
+    def image(self):
+        """
+        An |Image| object containing the image in this image part.
+        """
+        return Image(self.blob, self.desc)
 
     def scale(self, scaled_cx, scaled_cy):
         """
@@ -83,19 +104,6 @@ class ImagePart(Part):
         """
         return hashlib.sha1(self._blob).hexdigest()
 
-    @property
-    def _desc(self):
-        """
-        Return filename associated with this image, either the filename of
-        the original image file the image was created with or a synthetic
-        name of the form ``image.ext`` where ``ext`` is appropriate to the
-        image file format, e.g. ``'jpg'``.
-        """
-        # return generic filename if original filename is unknown
-        if self._filename is None:
-            return 'image.%s' % self.ext
-        return self._filename
-
     @property
     def _dpi(self):
         """
